-- ncrx colors != ssc colors
--[[ generic functions ]]
function BrightColor( c )
	local multiplier = 1.5;

	local r = c[1];
	local g = c[2];
	local b = c[3];

	r = r * multiplier;
	if r > 1 then
		r = scale( r, 1, multiplier, 1/multiplier, 1 );
	end

	g = g * multiplier;
	if g > 1 then
		g = scale( g, 1, multiplier, 1/multiplier, 1 );
	end

	b = b * multiplier;
	if b > 1 then
		b = scale( b, 1, multiplier, 1/multiplier, 1 );
	end

	return { r, g, b, c[4] };
end;

function MidColor( c )
	return { c[1]/1.5, c[2]/1.5, c[3]/1.5, c[4] };
end;

function DarkColor( c )
	return { c[1]/2, c[2]/2, c[3]/2, c[4] };
end;
--[[ /generic functions ]]

--[[ player colors ]]
function PlayerColor( pn )
	if pn == PLAYER_1 then return color("#ff358b") end	-- red
	if pn == PLAYER_2 then return color("#01b0f0") end	-- blue
	return color("1,1,1,1")
end

function PlayerMidColor( pn )
	return MidColor( PlayerColor(pn) );
end;

function PlayerDarkColor( pn )
	return DarkColor( PlayerColor(pn) );
end;
--[[ /player colors ]]

--[[ song length colors ]]
-- todo: perfect them
SongLengthColors = {
	Normal   = color("#FFFFFF"),
	Long     = color("#00DD00"),
	Marathon = color("#FF8800"),
};
--[[ /song length colors ]]

--[[ difficulty colors ]]
-- kill off DifficultyColors.
DifficultyColors = nil;

-- generic colors that are re-used
--[[
local cGenericBeginner = color("#12D7FF"); -- light blue
local cGenericEasy = color("#12FF39"); -- green
local cGenericMedium = color("#FF12D7"); -- pink/purple
local cGenericHard = color("#FF3912"); -- red
local cGenericChallenge = color("#3912FF"); -- blue
local cGenericEdit = color("#888888"); -- gray
--]]

-- difficulty colors:
-- [begi-LGreen] [easy-Yellow] [medi-Orange] [hard-Red] [expt-Blue] [edit-Gray]
local cGenericBeginner  = Colors.NeonMint;
local cGenericEasy      = Colors.Yellow;
local cGenericMedium    = Colors.Orange;
local cGenericHard      = Colors.Red;
local cGenericChallenge = Colors.Cerulean;
local cGenericEdit      = Colors.Manatee;

CustomDifficultyColors = {
	Beginner = cGenericBeginner,
	Easy = cGenericEasy,
	Medium = cGenericMedium,
	Hard = cGenericHard,
	Challenge = cGenericChallenge,
	Edit = cGenericEdit,
};

DifficultyAndStepsTypeInfo = {
	--[[ dance mode ]]
	-- single
	{ difficulty = "Difficulty_Beginner", stepsType = "StepsType_Dance_Single", color = cGenericBeginner },
	{ difficulty = "Difficulty_Easy", stepsType = "StepsType_Dance_Single", color = cGenericEasy },
	{ difficulty = "Difficulty_Medium", stepsType = "StepsType_Dance_Single", color = cGenericMedium },
	{ difficulty = "Difficulty_Hard", stepsType = "StepsType_Dance_Single", color = cGenericHard },
	{ difficulty = "Difficulty_Challenge", stepsType = "StepsType_Dance_Single", color = cGenericChallenge },
	{ difficulty = "Difficulty_Edit", stepsType = "StepsType_Dance_Single", color = cGenericEdit },
	-- double
	{ difficulty = "Difficulty_Beginner", stepsType = "StepsType_Dance_Double", color = cGenericBeginner },
	{ difficulty = "Difficulty_Easy", stepsType = "StepsType_Dance_Double", color = cGenericEasy },
	{ difficulty = "Difficulty_Medium", stepsType = "StepsType_Dance_Double", color = cGenericMedium },
	{ difficulty = "Difficulty_Hard", stepsType = "StepsType_Dance_Double", color = cGenericHard },
	{ difficulty = "Difficulty_Challenge", stepsType = "StepsType_Dance_Double", color = cGenericChallenge },
	{ difficulty = "Difficulty_Edit", stepsType = "StepsType_Dance_Double", color = cGenericEdit },

	--[[ pump mode ]]
	{ difficulty = "Difficulty_Beginner", stepsType = "StepsType_Pump_Single", color = cGenericBeginner },
	{ difficulty = "Difficulty_Easy", stepsType = "StepsType_Pump_Single", color = cGenericEasy },
	{ difficulty = "Difficulty_Medium", stepsType = "StepsType_Pump_Single", color = cGenericMedium },
	{ difficulty = "Difficulty_Hard", stepsType = "StepsType_Pump_Single", color = cGenericHard },
	{ difficulty = "Difficulty_Challenge", stepsType = "StepsType_Pump_Single", color = cGenericChallenge },
	{ difficulty = "Difficulty_Edit", stepsType = "StepsType_Pump_Single", color = cGenericEdit },
	--[[ todo:
	* Half doubles (Medium / Pump_Halfdouble) [#04feba in pro; unknown here]
	* freestyle (Medium / Pump_Double) [#fe04f5 in pro; will probably be orange]
	* nightmare (Hard / Pump_Double) [#04c6fe in pro; will probably be darker gray]
	]]
	{ difficulty = "Difficulty_Edit", stepsType = "StepsType_Pump_Halfdouble", color = cGenericEdit },
	{ difficulty = "Difficulty_Edit", stepsType = "StepsType_Pump_Double", color = cGenericEdit },
};

function CustomDifficultyToColor(sCustomDifficulty)
	return CustomDifficultyColors[sCustomDifficulty] or Colors.Black;
end;

difficultyToColor = {
	Difficulty_Beginner = cGenericChallenge,
	Difficulty_Easy = cGenericEasy,
	Difficulty_Medium = cGenericMedium,
	Difficulty_Hard = cGenericHard,
	Difficulty_Challenge = cGenericChallenge,
};

function CourseDifficultyToColor(difficulty)
	return difficultyToColor[difficulty];
end;

--[[
function StepsOrTrailToColor(StepsOrTrail)
	if not StepsOrTrail then return color("#000000"); end
	if lua.CheckType("Trail", StepsOrTrail) then return TrailColor() end

	local dc = StepsOrTrail:GetDifficulty();
	local st = StepsOrTrail.GetStepsType and StepsOrTrail:GetStepsType();
	return DifficultyAndStepsTypeToColor( dc, st );
end

function DifficultyAndStepsTypeToIndex( difficulty, stepsType )
	for idx, entry in ipairs(DifficultyAndStepsTypeInfo) do
		if entry.difficulty == difficulty and entry.stepsType == stepsType then 
			return idx;
		end
	end
	return nil;
end

function DifficultyAndStepsTypeToColor( difficulty, stepsType )
	local idx = DifficultyAndStepsTypeToIndex( difficulty, stepsType );
	if not idx then return color("#000000"); end
	return DifficultyAndStepsTypeInfo[idx].color;
end
--]]
--[[ /difficulty colors ]]

--[[ tap judgment colors ]]
local JudgeColors = {
	TapNoteScore_W1 = color("#FFFFCC"),   -- Perfect / light goldish
	TapNoteScore_W2 = color("#FFDD00"),   -- Superb / gold
	TapNoteScore_W3 = color("#00DD00"),   -- Great / green
	TapNoteScore_W4 = color("#00C0FF"),   -- Good / aj blue
	TapNoteScore_W5 = color("#CC00FF"),   -- Boo / purple
	TapNoteScore_Miss = color("#DB2122"), -- Miss / red
};
function JudgeColor( jc ) return JudgeColors[jc] end
--[[ /tap judgment colors ]]

--[[ old code ]]
--[[
local DifficultyColors = {
	Difficulty_Beginner		= color("#12D7FF"),	-- light blue
	Difficulty_Easy			= color("#12FF39"),	-- green
	Difficulty_Medium		= color("#FF12D7"),	-- pink/purple
	Difficulty_Hard			= color("#FF3912"),	-- red
	Difficulty_Challenge	= color("#3912FF"),	-- blue
	Difficulty_Edit			= color("#888888"),	-- dark gray
}
function DifficultyColor( dc ) return DifficultyColors[dc] end

function DifficultyLightColor( dc )
	local c = DifficultyColor(dc);
	return { c[1]+(c[1]/2), c[2]+(c[2]/2), c[3]+(c[3]/2), c[4] };
end;

function DifficultyDarkColor( dc )
	local c = DifficultyColor(dc);
	return { c[1]/2, c[2]/2, c[3]/2, c[4] };
end;
]]
--[[ /old code ]]