-- ncrx custom option rows [req. envutils2]

--[[
Score Events:
SE_CheckpointHit,
SE_W1,
SE_W2,
SE_W3,
SE_W4,
SE_W5,
SE_Miss,
SE_HitMine,
SE_CheckpointMiss,
SE_Held,
SE_LetGo,
--]]
local ScoreEvents = {
	CheckpointHit = 'TapNoteScore_CheckpointHit',
	W1 = 'TapNoteScore_W1',
	W2 = 'TapNoteScore_W2',
	W3 = 'TapNoteScore_W3',
	W4 = 'TapNoteScore_W4',
	W5 = 'TapNoteScore_W5',
	Miss = 'TapNoteScore_Miss',
	HitMine = 'TapNoteScore_HitMine',
	CheckpointMiss = 'TapNoteScore_CheckpointMiss',
	Held = 'HoldNoteScore_Held',
	LetGo = 'HoldNoteScore_LetGo',
};

local GradeWeights = {
	Default	= {
		CheckpointHit = 0,
		W1 = 2,
		W2 = 2,
		W3 = 1,
		W4 = 0,
		W5 = -4,
		Miss = -8,
		HitMine = -8,
		CheckpointMiss = 0,
		Held = 6,
		LetGo = 0,
	},
	OldDDR	= {
		CheckpointHit = 0,
		W1 = 2,
		W2 = 2,
		W3 = 1,
		W4 = 0,
		W5 = -4,
		Miss = -5,
		HitMine = -5,
		CheckpointMiss = 0,
		Held = 0,
		LetGo = 0,
	},
	MIGS	= {
		CheckpointHit = 0,
		W1 = 3,
		W2 = 2,
		W3 = 1,
		W4 = 0,
		W5 = -4,
		Miss = -8,
		HitMine = -8,
		CheckpointMiss = 0,
		Held = 6,
		LetGo = 0,
	},
	-- taken from openitg default
	ITG		= {
		CheckpointHit = 0,
		W1 = 5,
		W2 = 4,
		W3 = 2,
		W4 = 0,
		W5 = 6,
		Miss = -12,
		HitMine = -6,
		CheckpointMiss = 0,
		Held = 5,
		LetGo = 0,
	},
	PumpPro	= {
		CheckpointHit = 0,
		W1 = 10,
		W2 = 8,
		W3 = 6,
		W4 = 2,
		W5 = -2,
		Miss = -2,
		HitMine = -8,
		CheckpointMiss = 0,
		Held = 6,
		LetGo = 0,
	},
};

local PercentScoreWeight = {
	Default	= {
		CheckpointHit = 0,
		W1 = 3,
		W2 = 2,
		W3 = 1,
		W4 = 0,
		W5 = 0,
		Miss = 0,
		HitMine = -2,
		CheckpointMiss = 0,
		Held = 3,
		LetGo = 0,
	},

	-- wrong?
	OldDDR	= {
		CheckpointHit = 0,
		W1 = 2,
		W2 = 2,
		W3 = 1,
		W4 = 0,
		W5 = -4,
		Miss = -5,
		HitMine = -5,
		CheckpointMiss = 0,
		Held = 0,
		LetGo = 0,
	},

	-- wrong?
	MIGS	= {
		CheckpointHit = 0,
		W1 = 3,
		W2 = 2,
		W3 = 1,
		W4 = 0,
		W5 = -4,
		Miss = -8,
		HitMine = -8,
		CheckpointMiss = 0,
		Held = 6,
		LetGo = 0,
	},

	ITG		= {
		CheckpointHit = 0,
		W1 = 5,
		W2 = 4,
		W3 = 2,
		W4 = 0,
		W5 = -6,
		Miss = -12,
		HitMine = -6,
		CheckpointMiss = 0,
		Held = 5,
		LetGo = 0,
	},

	-- ok
	PumpPro	= {
		CheckpointHit = 0,
		W1 = 10,
		W2 = 8,
		W3 = 6,
		W4 = 2,
		W5 = -2,
		Miss = -2,
		HitMine = -2,
		CheckpointMiss = 0,
		Held = 3,
		LetGo = 0,
	},
};

-- PercentScoreSystem=[Default,OldDDR,MIGS,ITG,PumpPro]
local function PercentScorePrefHelper(mode)
	-- the helper goes through and modifies PrefsMan values and sets the userpref
	for se, val in pairs(PercentScoreWeight[mode]) do
		PREFSMAN:SetPreference("PercentScoreWeight"..se,val);
	end;
	SetUserPref("PercentScoreSystem",mode);
end;

-- option rows
function OptionRowPercentScoreSystem()
	local t = {
		-- Name is used to retrieve the header and explanation text.
		Name = "Percent Scoring System";
		LayoutType = "ShowAllInRow";
		SelectType = "SelectOne";
		OneChoiceForAllPlayers = true;
		ExportOnChange = false;
		Choices = { 'Default','OldDDR','MIGS','ITG','PumpPro' };
		LoadSelections = function(self, list, pn)
			local scoreSystem = GetUserPref("PercentScoreSystem");
			if not scoreSystem then SetUserPref("PercentScoreSystem","Default"); end;
			if scoreSystem == "Default" then list[1] = true;
			elseif scoreSystem == "OldDDR" then list[2] = true;
			elseif scoreSystem == "MIGS" then list[3] = true;
			elseif scoreSystem == "ITG" then list[4] = true;
			elseif scoreSystem == "PumpPro" then list[5] = true;
			else list[1] = true; -- fallback to default
			end;
		end;
		SaveSelections = function(self, list, pn)
			local mode = nil;
			if list[1] then mode = "Default";
			elseif list[2] then mode = "OldDDR";
			elseif list[3] then mode = "MIGS";
			elseif list[4] then mode = "ITG";
			elseif list[5] then mode = "PumpPro";
			else mode = "Default"; -- fallback
			end;
			PercentScorePrefHelper(mode);
		end;
	};
	setmetatable( t, t );
	return t;
end;